@@ -22,11 +22,8 @@
 #include "xbmcconnection.h"
 
 Playlist::Playlist(Player *parent) :
-    XbmcModel(0),
     m_currentItem(-1),
-    m_shuffle(false), //TODO: query player for state as soon as API supports it
-    m_player(parent),
-    m_repeat(RepeatOne)
+    m_player(parent)
 {
     connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReveiced(int,QVariantMap)));
     connect(XbmcConnection::notifier(), SIGNAL(receivedAnnouncement(QVariantMap)), SLOT(receivedAnnouncement(QVariantMap)));
@@ -40,10 +37,11 @@ Player *Playlist::player() const
 
 void Playlist::addItems(const PlaylistItem &item)
 {
-    QVariantMap itemMap;
-    itemMap.insert("item", item.toMap());
+    QVariantMap params;
+    params.insert("item", item.toMap());
+    params.insert("playlistid", playlistId());
 
-    XbmcConnection::sendCommand(namespaceString() + ".Add", itemMap);
+    XbmcConnection::sendCommand("Playlist.Add", params);
 
     refresh();
 }
@@ -52,74 +50,61 @@ void Playlist::removeItem(int index)
 {
     QVariantMap params;
     params.insert("item", index);
-    XbmcConnection::sendCommand(namespaceString() + ".Remove", params);
+    params.insert("playlistid", playlistId());
+    XbmcConnection::sendCommand("Playlist.Remove", params);
 
     refresh();
 }
 
 void Playlist::clear()
 {
-    XbmcConnection::sendCommand(namespaceString() + ".Clear");
+    QVariantMap params;
+    params.insert("playlistid", playlistId());
+    XbmcConnection::sendCommand("Playlist.Clear", params);
     refresh();
 }
 
-void Playlist::addPlaylist(const QString &playlistId)
+void Playlist::addPlaylist(const QString &playlist)
 {
     PlaylistItem pItem;
-    pItem.setPlayList(playlistId);
-    QVariantMap item;
-    item.insert("item", pItem.toMap());
+    pItem.setPlayList(playlist);
 
-    XbmcConnection::sendCommand(namespaceString() + ".Add", item);
+    QVariantMap params;
+    params.insert("item", pItem.toMap());
+    params.insert("playlistid", playlistId());
+
+    XbmcConnection::sendCommand("Playlist.Add", params);
+    refresh();
 }
 
 void Playlist::addFile(const QString &file)
 {
     PlaylistItem pItem;
     pItem.setFile(file);
-    QVariantMap item;
-    item.insert("item", pItem.toMap());
-    XbmcConnection::sendCommand(namespaceString() + ".Add", item);
+
+    QVariantMap params;
+    params.insert("item", pItem.toMap());
+    params.insert("playlistid", playlistId());
+
+    XbmcConnection::sendCommand("Playlist.Add", params);
+    refresh();
+}
+
+void Playlist::addDirectory(const QString &dir)
+{
+    PlaylistItem pItem;
+    pItem.setDirectory(dir);
+
+    QVariantMap params;
+    params.insert("item", pItem.toMap());
+    params.insert("playlistid", playlistId());
+
+    XbmcConnection::sendCommand("Playlist.Add", params);
     refresh();
 }
 
 void Playlist::receivedAnnouncement(const QVariantMap &map)
 {
-    if(map.value("method").toString() == "Player.QueueNextItem") {
-    } else if(map.value("method").toString() == "Player.OnPlay") {
-        qDebug() << "current has changed!";
-        emit currentChanged();
-    }
-}
-
-void Playlist::playItem(int index)
-{
-    QVariantMap map;
-    map.insert("item", index);
-    XbmcConnection::sendCommand(namespaceString() + ".Play", map);
-    m_currentItem = index;
-    qDebug() << namespaceString() + "setting current to" << m_currentItem;
-    emit currentChanged();
-}
-
-void Playlist::skipPrevious()
-{
-    if(m_currentItem > 0) {
-        XbmcConnection::sendCommand(namespaceString() + ".SkipPrevious");
-        m_currentItem--;
-        qDebug() << "(4)settings current to" << m_currentItem;
-        emit currentChanged();
-    }
-}
-
-void Playlist::skipNext()
-{
-    if(m_currentItem < count() - 1) {
-        XbmcConnection::sendCommand(namespaceString() + ".SkipNext");
-        m_currentItem++;
-        qDebug() << "(3)settings current to" << m_currentItem;
-        emit currentChanged();
-    }
 }
 
 int Playlist::currentTrackNumber() const
@@ -132,52 +117,6 @@ int Playlist::count() const
     return rowCount();
 }
 
-bool Playlist::shuffle() const
-{
-    return m_shuffle;
-}
-
-void Playlist::setShuffle(bool shuffle)
-{
-    if(shuffle) {
-        XbmcConnection::sendCommand(namespaceString() + ".Shuffle");
-    } else {
-        XbmcConnection::sendCommand(namespaceString() + ".UnShuffle");
-    }
-    if(m_shuffle != shuffle) {
-        m_shuffle = shuffle;
-        emit shuffleChanged();
-    }
-}
-
-void Playlist::setRepeat(Playlist::Repeat repeat)
-{
-    QVariantMap params;
-    switch(repeat) {
-    case RepeatNone:
-        params.insert("state", "off");
-        break;
-    case RepeatOne:
-        params.insert("state", "one");
-        break;
-    case RepeatAll:
-        params.insert("state", "all");
-        break;
-    }
-
-    XbmcConnection::sendCommand(namespaceString() + ".Repeat", params);
-
-    if(m_repeat != repeat) {
-        m_repeat = repeat;
-        emit repeatChanged();
-    }
-}
-
-Playlist::Repeat Playlist::repeat() const
-{
-    return m_repeat;
-}
-
 PlaylistItem* Playlist::currentItem() const
 {
     if(m_currentItem == -1 || m_currentItem >= count()) {
@@ -185,3 +124,10 @@ PlaylistItem* Playlist::currentItem() const
     }
     return at(m_currentItem);
 }
+
+void Playlist::setCurrentIndex(int index)
+{
+    m_currentItem = index;
+    queryItemData(m_currentItem);
+    emit currentChanged();
+}
