@@ -18,6 +18,7 @@
 
 #include "xbmc.h"
 #include "xbmcconnection.h"
+#include "xdebug.h"
 
 #include "audiolibrary.h"
 #include "artists.h"
@@ -32,12 +33,15 @@
 
 #include "audioplayer.h"
 #include "videoplayer.h"
+#include "pictureplayer.h"
 
 #include "audioplaylistitem.h"
 #include "videoplaylistitem.h"
 
 #include "keys.h"
 
+#include "settings.h"
+
 #include <QSettings>
 #include <QtDeclarative>
 
@@ -61,6 +65,7 @@ Xbmc::Xbmc(QObject *parent) :
     qmlRegisterType<Player>();
     qmlRegisterType<AudioPlayer>();
     qmlRegisterType<VideoPlayer>();
+    qmlRegisterType<PicturePlayer>();
     qmlRegisterType<Playlist>();
     qmlRegisterType<PlaylistItem>();
     qmlRegisterType<AudioPlaylistItem>();
@@ -69,13 +74,15 @@ Xbmc::Xbmc(QObject *parent) :
     qmlRegisterType<Shares>();
     qmlRegisterType<Keys>();
 
-    qmlRegisterType<AudioPlaylist>("Xbmc", 1, 0, "Playlist");
+    qmlRegisterType<AudioPlayer>("Xbmc", 1, 0, "Player");
 
     QSettings settings("xbmcremote");
     m_hostname = settings.value("Host").toString();
     m_port = settings.value("Port", 8080).toInt();
+    m_username = settings.value("Username").toString();
+    m_password = settings.value("Password").toString();
 
-    XbmcConnection::connect(m_hostname, m_port);
+    XbmcConnection::connect(m_hostname, m_port, m_username, m_password);
 //    XbmcConnection::connect("10.10.10.10", 8080);
 
     connect(XbmcConnection::notifier(), SIGNAL(connectionChanged()), SLOT(connectionChanged()));
@@ -84,10 +91,16 @@ Xbmc::Xbmc(QObject *parent) :
 
     m_audioPlayer = new AudioPlayer(this);
     m_videoPlayer = new VideoPlayer(this);
+    m_picturePlayer = new PicturePlayer(this);
     m_activePlayer = m_audioPlayer;
     m_state = "undefined";
+    m_picturePlayerActive = false;
 
     m_keys = new Keys(this);
+
+    m_volumeAnimation.setTargetObject(this);
+    m_volumeAnimation.setPropertyName("volume");
+    m_volumeAnimation.setDuration(500);
 }
 
 Xbmc::~Xbmc()
@@ -96,14 +109,13 @@ Xbmc::~Xbmc()
 
 void Xbmc::init()
 {
-    int id = XbmcConnection::sendCommand("Player.GetActivePlayers");
-    m_requestMap.insert(id, RequestActivePlayer);
+    queryActivePlayers();
 
     QVariantMap params;
     QVariantList list;
     list.append("volume");
     params.insert("properties", list);
-    id = XbmcConnection::sendCommand("Application.GetProperties", params);
+    int id = XbmcConnection::sendCommand("Application.GetProperties", params);
     m_requestMap.insert(id, RequestVolume);
 
 }
@@ -143,6 +155,11 @@ VideoPlayer *Xbmc::videoPlayer()
     return m_videoPlayer;
 }
 
+PicturePlayer *Xbmc::picturePlayer()
+{
+    return m_picturePlayer;
+}
+
 QString Xbmc::hostname()
 {
     return m_hostname;
@@ -169,24 +186,45 @@ void Xbmc::setPort(int port)
     emit portChanged();
 }
 
+QString Xbmc::username()
+{
+    return m_username;
+}
+
+void Xbmc::setUsername(const QString &username)
+{
+    QSettings settings("xbmcremote");
+    settings.setValue("Username", username);
+    m_username = username;
+    emit usernameChanged();
+}
+
+QString Xbmc::password()
+{
+    return m_password;
+}
+
+void Xbmc::setPassword(const QString &password)
+{
+    QSettings settings("xbmcremote");
+    settings.setValue("Password", password);
+    m_password = password;
+    emit passwordChanged();
+}
+
 void Xbmc::connectToHost()
 {
-    XbmcConnection::connect(m_hostname, m_port);
+    XbmcConnection::connect(m_hostname, m_port, m_username, m_password);
 }
 
 Player *Xbmc::activePlayer()
 {
+//    qDebug() << "returning active player" << m_activePlayer;
     return m_activePlayer;
 }
 
 void Xbmc::parseAnnouncement(const QVariantMap &map)
 {
-    QString method = map.value("method").toString();
-    qDebug() << "incoming announcement" << map << "method:" << method;
-    if(method == "Player.OnPlay" || method == "Player.OnStop") {
-        int id = XbmcConnection::sendCommand("Player.GetActivePlayers");
-        m_requestMap.insert(id, RequestActivePlayer);
-    }
 }
 
 void Xbmc::responseReceived(int id, const QVariantMap &response)
@@ -201,28 +239,40 @@ void Xbmc::responseReceived(int id, const QVariantMap &response)
 
     switch(m_requestMap.value(id)) {
     case RequestActivePlayer: {
-        qDebug() << "active player response:" << rsp;
-        QVariantMap activePlayerMap = rsp.toMap();
-        if(activePlayerMap.value("audio").toBool() == true) {
-            activePlayer = m_audioPlayer;
-            m_state = "audio";
-        } else if(activePlayerMap.value("video").toBool() == true) {
-            activePlayer = m_videoPlayer;
-            m_state = "video";
-//        } else if(activePlayerMap.value("pictures").toBool() == true) {
-//            activePlayer = m_picturePlayer;
-        } else {
-            activePlayer = 0;
+        // {"id":8,"jsonrpc":"2.0","result":[{"playerid":0,"type":"audio"}]}
+        xDebug(XDAREA_PLAYER) << "active player response:" << rsp;
+        QVariantList activePlayers = rsp.toList();
+        bool picturesActive = false;
+        foreach(const QVariant &activePlayerMap, activePlayers) {
+            if(activePlayerMap.toMap().value("type").toString() == "audio") {
+                activePlayer = m_audioPlayer;
+                m_state = "audio";
+            } else if(activePlayerMap.toMap().value("type").toString() == "video") {
+                activePlayer = m_videoPlayer;
+                m_state = "video";
+            }
+            if(activePlayerMap.toMap().value("type").toString() == "picture"){
+                picturesActive = true;
+            }
         }
-        if(m_activePlayer != activePlayer) {
+
+        if(activePlayer == 0) {
+            m_state = "";
+        } else if(m_activePlayer != activePlayer) {
             m_activePlayer = activePlayer;
-            qDebug() << "active player changed!";
+            xDebug(XDAREA_PLAYER) << "active player changed!";
             emit stateChanged();
             emit activePlayerChanged();
         }
         if(m_activePlayer) {
-            m_activePlayer->playlist()->refresh();
+            m_activePlayer->refresh();
         }
+
+        if(m_picturePlayerActive != picturesActive) {
+            m_picturePlayerActive = picturesActive;
+            emit picturePlayerActiveChanged();
+        }
+
         }
         break;
     case RequestVolume:
@@ -255,7 +305,6 @@ void Xbmc::connectionChanged()
     if(connected()) {
         init();
     }
-    qDebug() << "Connection changed to " << connected();
     emit connectedChanged(connected());
 }
 
@@ -267,12 +316,19 @@ void Xbmc::setVolume(int volume)
     if(volume > 100) {
         volume = 100;
     }
-    if(volume != m_volume) {
-        QVariantMap map;
-        map.insert("value", volume);
-        XbmcConnection::sendCommand("Application.SetVolume", map);
-        m_volume = volume;
-        emit volumeChanged(m_volume);
+
+    Settings settings;
+    if(!settings.volumeUpCommand().isEmpty()) {
+        QProcess p;
+        p.execute(settings.volumeUpCommand(), QStringList() << QString::number(volume));
+    } else {
+        if(volume != m_volume) {
+            QVariantMap map;
+            map.insert("value", volume);
+            XbmcConnection::sendCommand("Application.SetVolume", map);
+            m_volume = volume;
+            emit volumeChanged(m_volume);
+        }
     }
 }
 
@@ -285,3 +341,28 @@ void Xbmc::quit()
 {
     XbmcConnection::sendCommand("XBMC.Quit");
 }
+
+void Xbmc::dimVolumeTo(int newVolume)
+{
+    m_volumeAnimation.setDirection(QAbstractAnimation::Forward);
+    m_volumeAnimation.setStartValue(m_volume);
+    m_volumeAnimation.setEndValue(newVolume);
+    m_volumeAnimation.start();
+}
+
+void Xbmc::restoreVolume()
+{
+    m_volumeAnimation.setDirection(QAbstractAnimation::Backward);
+    m_volumeAnimation.start();
+}
+
+bool Xbmc::picturePlayerActive()
+{
+    return m_picturePlayerActive;
+}
+
+void Xbmc::queryActivePlayers()
+{
+    int id = XbmcConnection::sendCommand("Player.GetActivePlayers");
+    m_requestMap.insert(id, RequestActivePlayer);
+}
